<?php

/**
 * Function to return the array of starter content for the theme.
 *
 * Passes it through the `purea_magazine_starter_content` filter before returning.
 *
 *
 * @return array A filtered array of args for the starter_content.
 */
function purea_magazine_get_starter_content() {

	// Define and register starter content to showcase the theme on new sites.
	$starter_content = array(

		// Specify the core-defined pages to create and add custom thumbnails to some of them.
		'posts'     => array(
			'front' => array(
				'post_type'    => 'page',
				'post_title'   => esc_html__( 'Home', 'purea-magazine' ),
				'post_content' => '',
				'template' => 'home-template.php',
			),
			'blog',
			'contact',
		),

		// Default to a static front page and assign the front and posts pages.
		'options'   => array(
			'show_on_front'  => 'page',
			'page_on_front'  => '{{front}}',
			'page_for_posts' => '{{blog}}',
			'blogdescription' => esc_html__( 'Simple, Creative Magazine WordPress theme', 'purea-magazine' ),
			'blogname' => 'Purea Magazine',
		),
		'attachments' => array(
			'featured-image-logo' => array(
				'post_title'   => esc_html__( 'Featured Logo', 'purea-magazine' ),
				'file'         => 'img/logo.png',
			),
		),
		'theme_mods'  => array(
			'custom_logo' => '{{featured-image-logo}}',
			'purea_magazine_display_site_title_tagline' => false,
			'purea_magazine_enable_top_bar_social_icons' => true,
			'purea_magazine_enable_top_bar_facebook_icon' => true,
			'purea_magazine_enable_top_bar_twitter_icon' => true,
			'purea_magazine_enable_top_bar_instagram_icon' => true,
			'purea_magazine_enable_top_bar_linkedin_icon' => true,
			'purea_magazine_enable_top_bar_pinterest_icon' => true,
		),

		'widgets' => array(
			'purea-magazine-hp-left-section' => array(
				'calendar',
				'recent-comments',
			),
			'purea-magazine-hp-main-section' => array(
				'meta_purea_magazine_featured_posts_widget' => array( 'purea_magazine_featured_posts_widget', array(
	                'section_title' => esc_html__( 'Featured Posts', 'purea-magazine' ),
	                'no_of_posts' => 3,
	                'category' => '-1',
	            ) ),
	            'meta_purea_magazine_posts_layout_1_widget' => array( 'purea_magazine_posts_layout_1_widget', array(
	                'section_title' => esc_html__( 'Posts Layout One', 'purea-magazine' ),
	                'no_of_posts' => 5,
	                'category' => '-1',
	            ) ),
	            'meta_purea_magazine_posts_layout_2_widget' => array( 'purea_magazine_posts_layout_2_widget', array(
	                'section_title' => esc_html__( 'Posts Layout Two', 'purea-magazine' ),
	                'no_of_posts' => 8,
	                'category' => '-1',
	            ) ),
			),
			'purea-magazine-hp-right-section' => array(
				'search',
				'meta_purea_magazine_latest_posts_widget' => array( 'purea_magazine_latest_posts_widget', array(
	                'section_title' => esc_html__( 'Latest Posts', 'purea-magazine' ),
	                'no_of_posts' => 5,
	                'category' => '-1',
	            ) ),
	            'meta_purea_magazine_top_categories_widget' => array( 'purea_magazine_top_categories_widget', array(
	                'section_title' => esc_html__( 'Top categories', 'purea-magazine' ),
	                'no_of_posts' => 5,
	                'category' => '-1',
	            ) ),
				'text_about',
			),
		),
		
		// Set up nav menus for each of the two areas registered in the theme.
		'nav_menus' => array(
			// Assign a menu to the "primary" location.
			'primary' => array(
				'name'  => esc_html__( 'Primary', 'purea-magazine' ),
				'items' => array(
					'link_home', // Note that the core "home" page is actually a link in case a static front page is not used.
					'page_blog',
					'page_contact',
				),
			),

			// Assign a menu to the "footer" location.
			'footer'  => array(
				'name'  => esc_html__( 'Footer', 'purea-magazine' ),
				'items' => array(
					'link_custom1'   =>  array(
                    	'title' =>  esc_html__( 'Science', 'purea-magazine' ),
                	),
                	'link_custom2'   =>  array(
                    	'title' =>  esc_html__( 'Technology', 'purea-magazine' ),
                	),
                	'link_custom3'   =>  array(
                    	'title' =>  esc_html__( 'Sports', 'purea-magazine' ),
                	),
                	'link_custom4'   =>  array(
                    	'title' =>  esc_html__( 'Arts', 'purea-magazine' ),
                	),
				),
			),
		),
	);

	/**
	 * Filters the array of starter content.
	 *
	 *
	 * @param array $starter_content Array of starter content.
	 */
	return apply_filters( 'purea_magazine_starter_content', $starter_content );
}
